@@ -1,11 +1,11 @@
 '''pynetworks
 ==========
 
-A Python package that provides structure for networks of interconnected nodes
-using the DOT language for representation.
+A Python package that provides structure for networks of interconnected
+nodes using the DOT language for representation.
 '''
 
-from .networks import Connection
+from .networks import Edge
 from .networks import Network
 from .networks import Node
 from .networks import generate_network
@@ -18,17 +18,17 @@ from .pathfinding import shortest_path
 from .pathfinding import shortest_path_through_network
 
 
-__version__ = "0.5.2"
+__version__ = "0.6.0"
 
-__all__ = ['Connection',
+__all__ = ['Edge',
            'Network',
            'Node',
-           'Path',
+           'generate_network',
            'dotgraph',
            'escape_dot_id',
-           'generate_network',
+           'Path',
            'memoize',
            'path_exists',
            'shortest_path',
-           'shortest_path_through_network',
+           'shortest_path_through_network'
            ]
